@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAddressBook_VERSION = "5.3.2932"
+IAddressBook_VERSION = "5.4.2629"
 
 
 class IAddressBook(BaseEndpoint):
@@ -385,6 +385,20 @@ class IAddressBook(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.LONG), response)
 
+    def sortedUids(self, arg0):
+        postUri = "/_sorteduids"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
     def sync(self, since, changes):
         postUri = "/_sync"
         __data__ = None
