@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxFolders_VERSION = "5.3.2932"
+IMailboxFolders_VERSION = "5.4.2629"
 
 
 class IMailboxFolders(BaseEndpoint):
@@ -103,6 +103,20 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
 
+    def counters(self, folderItemIds):
+        postUri = "/_counters"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(folderItemIds)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFolders_VERSION}, data=__encoded__)
+        from netbluemind.backend.mail.api.FolderCounters import FolderCounters
+        from netbluemind.backend.mail.api.FolderCounters import __FolderCountersSerDer__
+        return self.handleResult__(serder.ListSerDer(__FolderCountersSerDer__()), response)
+
     def createBasic(self, value):
         postUri = ""
         __data__ = None
@@ -217,6 +231,17 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
 
+    def getFullName(self, uid):
+        postUri = "/{uid}/fullname"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFolders_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.STRING, response)
+
     def getVersion(self):
         postUri = "/_version"
         __data__ = None
