@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxItems_VERSION = "5.3.2932"
+IMailboxItems_VERSION = "5.4.2629"
 
 
 class IMailboxItems(BaseEndpoint):
@@ -184,6 +184,17 @@ class IMailboxItems(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxItems_VERSION}, data=__encoded__)
         return response.content
 
+    def fetchCompleteByGuid(self, guid):
+        postUri = "/eml_by_guid/{guid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{guid}", guid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxItems_VERSION}, data=__encoded__)
+        return response.content
+
     def filteredChangesetById(self, since, arg1):
         postUri = "/_filteredChangesetById"
         __data__ = None
@@ -350,6 +361,20 @@ class IMailboxItems(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxItems_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.LONG), response)
 
+    def sortedUids(self, arg0):
+        postUri = "/_sorteduids"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxItems_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
     def unexpunge(self, itemId):
         postUri = "/_unexpunge/{itemId}"
         __data__ = None
