@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IReadOnlyMailboxFolders_VERSION = "5.3.2932"
+IReadOnlyMailboxFolders_VERSION = "5.4.2629"
 
 
 class IReadOnlyMailboxFolders(BaseEndpoint):
@@ -134,6 +134,17 @@ class IReadOnlyMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
 
+    def getFullName(self, uid):
+        postUri = "/{uid}/fullname"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IReadOnlyMailboxFolders_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.STRING, response)
+
     def getVersion(self):
         postUri = "/_version"
         __data__ = None
