@@ -27,6 +27,7 @@ class MailboxFolder:
         self.fullName = None
         self.parentUid = None
         self.deleted = None
+        self.virtualFolder = None
         pass
 
 
@@ -51,6 +52,8 @@ class __MailboxFolderSerDer__:
         instance.parentUid = serder.STRING.parse(parentUidValue)
         deletedValue = value['deleted']
         instance.deleted = serder.BOOLEAN.parse(deletedValue)
+        virtualFolderValue = value['virtualFolder']
+        instance.virtualFolder = serder.BOOLEAN.parse(virtualFolderValue)
         return instance
 
     def encode(self, value):
@@ -70,4 +73,6 @@ class __MailboxFolderSerDer__:
         instance["parentUid"] = serder.STRING.encode(parentUidValue)
         deletedValue = value.deleted
         instance["deleted"] = serder.BOOLEAN.encode(deletedValue)
+        virtualFolderValue = value.virtualFolder
+        instance["virtualFolder"] = serder.BOOLEAN.encode(virtualFolderValue)
         return instance
