@@ -33,6 +33,7 @@ class SearchQuery:
         self.offset = None
         self.scope = None
         self.logicalOperator = None
+        self.trackScores = None
         pass
 
 
@@ -76,6 +77,8 @@ class __SearchQuerySerDer__:
         logicalOperatorValue = value['logicalOperator']
         instance.logicalOperator = __SearchQueryLogicalOperatorSerDer__().parse(
             logicalOperatorValue)
+        trackScoresValue = value['trackScores']
+        instance.trackScores = serder.BOOLEAN.parse(trackScoresValue)
         return instance
 
     def encode(self, value):
@@ -116,4 +119,6 @@ class __SearchQuerySerDer__:
         logicalOperatorValue = value.logicalOperator
         instance["logicalOperator"] = __SearchQueryLogicalOperatorSerDer__().encode(
             logicalOperatorValue)
+        trackScoresValue = value.trackScores
+        instance["trackScores"] = serder.BOOLEAN.encode(trackScoresValue)
         return instance
