@@ -29,6 +29,7 @@ class PrintOptions:
         self.dateEnd = None
         self.color = None
         self.showDetail = None
+        self.showCancelled = None
         self.layout = None
         self.calendars = None
         self.tagsFilter = None
@@ -68,6 +69,8 @@ class __PrintOptionsSerDer__:
         instance.color = serder.BOOLEAN.parse(colorValue)
         showDetailValue = value['showDetail']
         instance.showDetail = serder.BOOLEAN.parse(showDetailValue)
+        showCancelledValue = value['showCancelled']
+        instance.showCancelled = serder.BOOLEAN.parse(showCancelledValue)
         from netbluemind.calendar.api.PrintOptionsPrintLayout import PrintOptionsPrintLayout
         from netbluemind.calendar.api.PrintOptionsPrintLayout import __PrintOptionsPrintLayoutSerDer__
         layoutValue = value['layout']
@@ -112,6 +115,8 @@ class __PrintOptionsSerDer__:
         instance["color"] = serder.BOOLEAN.encode(colorValue)
         showDetailValue = value.showDetail
         instance["showDetail"] = serder.BOOLEAN.encode(showDetailValue)
+        showCancelledValue = value.showCancelled
+        instance["showCancelled"] = serder.BOOLEAN.encode(showCancelledValue)
         from netbluemind.calendar.api.PrintOptionsPrintLayout import PrintOptionsPrintLayout
         from netbluemind.calendar.api.PrintOptionsPrintLayout import __PrintOptionsPrintLayoutSerDer__
         layoutValue = value.layout
