@@ -29,6 +29,7 @@ class VEventQuery:
         self.escapeQuery = None
         self.dateMin = None
         self.dateMax = None
+        self.excludeStatus = None
         self.resolveAttendees = None
         self.attendee = None
         pass
@@ -63,6 +64,10 @@ class __VEventQuerySerDer__:
         from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
         dateMaxValue = value['dateMax']
         instance.dateMax = __BmDateTimeSerDer__().parse(dateMaxValue)
+        from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
+        from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
+        excludeStatusValue = value['excludeStatus']
+        instance.excludeStatus = __ICalendarElementStatusSerDer__().parse(excludeStatusValue)
         resolveAttendeesValue = value['resolveAttendees']
         instance.resolveAttendees = serder.BOOLEAN.parse(resolveAttendeesValue)
         from netbluemind.calendar.api.VEventAttendeeQuery import VEventAttendeeQuery
@@ -96,6 +101,11 @@ class __VEventQuerySerDer__:
         from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
         dateMaxValue = value.dateMax
         instance["dateMax"] = __BmDateTimeSerDer__().encode(dateMaxValue)
+        from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
+        from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
+        excludeStatusValue = value.excludeStatus
+        instance["excludeStatus"] = __ICalendarElementStatusSerDer__().encode(
+            excludeStatusValue)
         resolveAttendeesValue = value.resolveAttendees
         instance["resolveAttendees"] = serder.BOOLEAN.encode(
             resolveAttendeesValue)
