@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IContainers_VERSION = "5.3.2932"
+IContainers_VERSION = "5.4.2629"
 
 
 class IContainers(BaseEndpoint):
@@ -107,6 +107,18 @@ class IContainers(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def exists(self, containerUid):
+        postUri = "/_exists"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.STRING.encode(containerUid)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.BOOLEAN, response)
+
     def get(self, uid):
         postUri = "/{uid}"
         __data__ = None
