@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ISortingSupport_VERSION = "5.3.2932"
+ISortingSupport_VERSION = "5.4.2629"
 
 
 class ISortingSupport(BaseEndpoint):
@@ -44,3 +44,17 @@ class ISortingSupport(BaseEndpoint):
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISortingSupport_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.LONG), response)
+
+    def sortedUids(self, sorted):
+        postUri = "/_sorteduids"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(sorted)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISortingSupport_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
