@@ -39,6 +39,7 @@ class DirEntryQuery:
         self.entryUidFilter = None
         self.onlyManagable = None
         self.dataLocation = None
+        self.lightResults = None
         pass
 
 
@@ -100,6 +101,8 @@ class __DirEntryQuerySerDer__:
         instance.onlyManagable = serder.BOOLEAN.parse(onlyManagableValue)
         dataLocationValue = value['dataLocation']
         instance.dataLocation = serder.STRING.parse(dataLocationValue)
+        lightResultsValue = value['lightResults']
+        instance.lightResults = serder.BOOLEAN.parse(lightResultsValue)
         return instance
 
     def encode(self, value):
@@ -158,4 +161,6 @@ class __DirEntryQuerySerDer__:
         instance["onlyManagable"] = serder.BOOLEAN.encode(onlyManagableValue)
         dataLocationValue = value.dataLocation
         instance["dataLocation"] = serder.STRING.encode(dataLocationValue)
+        lightResultsValue = value.lightResults
+        instance["lightResults"] = serder.BOOLEAN.encode(lightResultsValue)
         return instance
