@@ -1,27 +1,28 @@
 #
 #  BEGIN LICENSE
 #  Copyright (c) Blue Mind SAS, 2012-2016
-# 
+#
 #  This file is part of BlueMind. BlueMind is a messaging and collaborative
 #  solution.
-# 
+#
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of either the GNU Affero General Public License as
 #  published by the Free Software Foundation (version 3 of the License).
-# 
-# 
+#
+#
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-# 
+#
 #  See LICENSE.txt
 #  END LICENSE
 #
 import requests
 from netbluemind.python import serder
 
-class ICalendarElement :
-    def __init__( self):
+
+class ICalendarElement:
+    def __init__(self):
         self.dtstart = None
         self.summary = None
         self.classification = None
@@ -46,12 +47,13 @@ class ICalendarElement :
         self.draft = None
         pass
 
+
 class __ICalendarElementSerDer__:
-    def __init__( self ):
+    def __init__(self):
         pass
 
     def parse(self, value):
-        if(value == None):
+        if (value == None):
             return None
         instance = ICalendarElement()
 
@@ -68,7 +70,8 @@ class __ICalendarElementSerDer__:
         from netbluemind.icalendar.api.ICalendarElementClassification import ICalendarElementClassification
         from netbluemind.icalendar.api.ICalendarElementClassification import __ICalendarElementClassificationSerDer__
         classificationValue = value['classification']
-        instance.classification = __ICalendarElementClassificationSerDer__().parse(classificationValue)
+        instance.classification = __ICalendarElementClassificationSerDer__().parse(
+            classificationValue)
         locationValue = value['location']
         instance.location = serder.STRING.parse(locationValue)
         descriptionValue = value['description']
@@ -78,7 +81,8 @@ class __ICalendarElementSerDer__:
         from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
         from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
         alarmValue = value['alarm']
-        instance.alarm = serder.ListSerDer(__ICalendarElementVAlarmSerDer__()).parse(alarmValue)
+        instance.alarm = serder.ListSerDer(
+            __ICalendarElementVAlarmSerDer__()).parse(alarmValue)
         from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
         from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
         statusValue = value['status']
@@ -86,7 +90,8 @@ class __ICalendarElementSerDer__:
         from netbluemind.icalendar.api.ICalendarElementAttendee import ICalendarElementAttendee
         from netbluemind.icalendar.api.ICalendarElementAttendee import __ICalendarElementAttendeeSerDer__
         attendeesValue = value['attendees']
-        instance.attendees = serder.ListSerDer(__ICalendarElementAttendeeSerDer__()).parse(attendeesValue)
+        instance.attendees = serder.ListSerDer(
+            __ICalendarElementAttendeeSerDer__()).parse(attendeesValue)
         from netbluemind.icalendar.api.ICalendarElementOrganizer import ICalendarElementOrganizer
         from netbluemind.icalendar.api.ICalendarElementOrganizer import __ICalendarElementOrganizerSerDer__
         organizerValue = value['organizer']
@@ -94,15 +99,18 @@ class __ICalendarElementSerDer__:
         from netbluemind.tag.api.TagRef import TagRef
         from netbluemind.tag.api.TagRef import __TagRefSerDer__
         categoriesValue = value['categories']
-        instance.categories = serder.ListSerDer(__TagRefSerDer__()).parse(categoriesValue)
+        instance.categories = serder.ListSerDer(
+            __TagRefSerDer__()).parse(categoriesValue)
         from netbluemind.core.api.date.BmDateTime import BmDateTime
         from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
         exdateValue = value['exdate']
-        instance.exdate = serder.SetSerDer(__BmDateTimeSerDer__()).parse(exdateValue)
+        instance.exdate = serder.SetSerDer(
+            __BmDateTimeSerDer__()).parse(exdateValue)
         from netbluemind.core.api.date.BmDateTime import BmDateTime
         from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
         rdateValue = value['rdate']
-        instance.rdate = serder.SetSerDer(__BmDateTimeSerDer__()).parse(rdateValue)
+        instance.rdate = serder.SetSerDer(
+            __BmDateTimeSerDer__()).parse(rdateValue)
         from netbluemind.icalendar.api.ICalendarElementRRule import ICalendarElementRRule
         from netbluemind.icalendar.api.ICalendarElementRRule import __ICalendarElementRRuleSerDer__
         rruleValue = value['rrule']
@@ -114,13 +122,16 @@ class __ICalendarElementSerDer__:
         conferenceIdValue = value['conferenceId']
         instance.conferenceId = serder.STRING.parse(conferenceIdValue)
         conferenceConfigurationValue = value['conferenceConfiguration']
-        instance.conferenceConfiguration = serder.MapSerDer(serder.STRING).parse(conferenceConfigurationValue)
+        instance.conferenceConfiguration = serder.MapSerDer(
+            serder.STRING).parse(conferenceConfigurationValue)
         from netbluemind.attachment.api.AttachedFile import AttachedFile
         from netbluemind.attachment.api.AttachedFile import __AttachedFileSerDer__
         attachmentsValue = value['attachments']
-        instance.attachments = serder.ListSerDer(__AttachedFileSerDer__()).parse(attachmentsValue)
+        instance.attachments = serder.ListSerDer(
+            __AttachedFileSerDer__()).parse(attachmentsValue)
         propertiesValue = value['properties']
-        instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
+        instance.properties = serder.MapSerDer(
+            serder.STRING).parse(propertiesValue)
         sequenceValue = value['sequence']
         instance.sequence = serder.INT.parse(sequenceValue)
         draftValue = value['draft']
@@ -128,10 +139,10 @@ class __ICalendarElementSerDer__:
         return instance
 
     def encode(self, value):
-        if(value == None):
+        if (value == None):
             return None
         instance = dict()
-        self.encodeInternal(value,instance)
+        self.encodeInternal(value, instance)
         return instance
 
     def encodeInternal(self, value, instance):
@@ -145,7 +156,8 @@ class __ICalendarElementSerDer__:
         from netbluemind.icalendar.api.ICalendarElementClassification import ICalendarElementClassification
         from netbluemind.icalendar.api.ICalendarElementClassification import __ICalendarElementClassificationSerDer__
         classificationValue = value.classification
-        instance["classification"] = __ICalendarElementClassificationSerDer__().encode(classificationValue)
+        instance["classification"] = __ICalendarElementClassificationSerDer__().encode(
+            classificationValue)
         locationValue = value.location
         instance["location"] = serder.STRING.encode(locationValue)
         descriptionValue = value.description
@@ -155,31 +167,38 @@ class __ICalendarElementSerDer__:
         from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
         from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
         alarmValue = value.alarm
-        instance["alarm"] = serder.ListSerDer(__ICalendarElementVAlarmSerDer__()).encode(alarmValue)
+        instance["alarm"] = serder.ListSerDer(
+            __ICalendarElementVAlarmSerDer__()).encode(alarmValue)
         from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
         from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
         statusValue = value.status
-        instance["status"] = __ICalendarElementStatusSerDer__().encode(statusValue)
+        instance["status"] = __ICalendarElementStatusSerDer__().encode(
+            statusValue)
         from netbluemind.icalendar.api.ICalendarElementAttendee import ICalendarElementAttendee
         from netbluemind.icalendar.api.ICalendarElementAttendee import __ICalendarElementAttendeeSerDer__
         attendeesValue = value.attendees
-        instance["attendees"] = serder.ListSerDer(__ICalendarElementAttendeeSerDer__()).encode(attendeesValue)
+        instance["attendees"] = serder.ListSerDer(
+            __ICalendarElementAttendeeSerDer__()).encode(attendeesValue)
         from netbluemind.icalendar.api.ICalendarElementOrganizer import ICalendarElementOrganizer
         from netbluemind.icalendar.api.ICalendarElementOrganizer import __ICalendarElementOrganizerSerDer__
         organizerValue = value.organizer
-        instance["organizer"] = __ICalendarElementOrganizerSerDer__().encode(organizerValue)
+        instance["organizer"] = __ICalendarElementOrganizerSerDer__().encode(
+            organizerValue)
         from netbluemind.tag.api.TagRef import TagRef
         from netbluemind.tag.api.TagRef import __TagRefSerDer__
         categoriesValue = value.categories
-        instance["categories"] = serder.ListSerDer(__TagRefSerDer__()).encode(categoriesValue)
+        instance["categories"] = serder.ListSerDer(
+            __TagRefSerDer__()).encode(categoriesValue)
         from netbluemind.core.api.date.BmDateTime import BmDateTime
         from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
         exdateValue = value.exdate
-        instance["exdate"] = serder.SetSerDer(__BmDateTimeSerDer__()).encode(exdateValue)
+        instance["exdate"] = serder.SetSerDer(
+            __BmDateTimeSerDer__()).encode(exdateValue)
         from netbluemind.core.api.date.BmDateTime import BmDateTime
         from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
         rdateValue = value.rdate
-        instance["rdate"] = serder.SetSerDer(__BmDateTimeSerDer__()).encode(rdateValue)
+        instance["rdate"] = serder.SetSerDer(
+            __BmDateTimeSerDer__()).encode(rdateValue)
         from netbluemind.icalendar.api.ICalendarElementRRule import ICalendarElementRRule
         from netbluemind.icalendar.api.ICalendarElementRRule import __ICalendarElementRRuleSerDer__
         rruleValue = value.rrule
@@ -191,16 +210,18 @@ class __ICalendarElementSerDer__:
         conferenceIdValue = value.conferenceId
         instance["conferenceId"] = serder.STRING.encode(conferenceIdValue)
         conferenceConfigurationValue = value.conferenceConfiguration
-        instance["conferenceConfiguration"] = serder.MapSerDer(serder.STRING).encode(conferenceConfigurationValue)
+        instance["conferenceConfiguration"] = serder.MapSerDer(
+            serder.STRING).encode(conferenceConfigurationValue)
         from netbluemind.attachment.api.AttachedFile import AttachedFile
         from netbluemind.attachment.api.AttachedFile import __AttachedFileSerDer__
         attachmentsValue = value.attachments
-        instance["attachments"] = serder.ListSerDer(__AttachedFileSerDer__()).encode(attachmentsValue)
+        instance["attachments"] = serder.ListSerDer(
+            __AttachedFileSerDer__()).encode(attachmentsValue)
         propertiesValue = value.properties
-        instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
+        instance["properties"] = serder.MapSerDer(
+            serder.STRING).encode(propertiesValue)
         sequenceValue = value.sequence
         instance["sequence"] = serder.INT.encode(sequenceValue)
         draftValue = value.draft
         instance["draft"] = serder.BOOLEAN.encode(draftValue)
         return instance
-
