@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxes_VERSION = "5.3.2932"
+IMailboxes_VERSION = "5.4.2629"
 
 
 class IMailboxes(BaseEndpoint):
@@ -117,16 +117,6 @@ class IMailboxes(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
-    def byType(self, email):
-        postUri = "/_byType"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'email': email}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxes_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-
     def create(self, uid, mailbox):
         postUri = "/{uid}"
         __data__ = None
