@@ -24,6 +24,7 @@ from netbluemind.python import serder
 class ShardStatsMailboxStats:
     def __init__(self):
         self.mailboxUid = None
+        self.aliasName = None
         self.docCount = None
         pass
 
@@ -43,6 +44,8 @@ class __ShardStatsMailboxStatsSerDer__:
     def parseInternal(self, value, instance):
         mailboxUidValue = value['mailboxUid']
         instance.mailboxUid = serder.STRING.parse(mailboxUidValue)
+        aliasNameValue = value['aliasName']
+        instance.aliasName = serder.STRING.parse(aliasNameValue)
         docCountValue = value['docCount']
         instance.docCount = serder.LONG.parse(docCountValue)
         return instance
@@ -58,6 +61,8 @@ class __ShardStatsMailboxStatsSerDer__:
 
         mailboxUidValue = value.mailboxUid
         instance["mailboxUid"] = serder.STRING.encode(mailboxUidValue)
+        aliasNameValue = value.aliasName
+        instance["aliasName"] = serder.STRING.encode(aliasNameValue)
         docCountValue = value.docCount
         instance["docCount"] = serder.LONG.encode(docCountValue)
         return instance
