@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-INote_VERSION = "5.3.2932"
+INote_VERSION = "5.4.2629"
 
 
 class INote(BaseEndpoint):
@@ -322,6 +322,20 @@ class INote(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.LONG), response)
 
+    def sortedUids(self, arg0):
+        postUri = "/_sorteduids"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
     def update(self, uid, note):
         postUri = "/{uid}"
         __data__ = None
