@@ -1,19 +1,19 @@
 #
 #  BEGIN LICENSE
 #  Copyright (c) Blue Mind SAS, 2012-2016
-# 
+#
 #  This file is part of BlueMind. BlueMind is a messaging and collaborative
 #  solution.
-# 
+#
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of either the GNU Affero General Public License as
 #  published by the Free Software Foundation (version 3 of the License).
-# 
-# 
+#
+#
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-# 
+#
 #  See LICENSE.txt
 #  END LICENSE
 #
@@ -22,8 +22,10 @@ from netbluemind.python import serder
 
 from netbluemind.directory.api.DirBaseValue import DirBaseValue
 from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
+
+
 class ResourceDescriptor (DirBaseValue):
-    def __init__( self):
+    def __init__(self):
         DirBaseValue.__init__(self)
         self.label = None
         self.typeIdentifier = None
@@ -32,12 +34,13 @@ class ResourceDescriptor (DirBaseValue):
         self.properties = None
         pass
 
+
 class __ResourceDescriptorSerDer__:
-    def __init__( self ):
+    def __init__(self):
         pass
 
     def parse(self, value):
-        if(value == None):
+        if (value == None):
             return None
         instance = ResourceDescriptor()
 
@@ -45,7 +48,7 @@ class __ResourceDescriptorSerDer__:
         return instance
 
     def parseInternal(self, value, instance):
-        __DirBaseValueSerDer__().parseInternal(value,instance)
+        __DirBaseValueSerDer__().parseInternal(value, instance)
         labelValue = value['label']
         instance.label = serder.STRING.parse(labelValue)
         typeIdentifierValue = value['typeIdentifier']
@@ -59,18 +62,19 @@ class __ResourceDescriptorSerDer__:
         from netbluemind.resource.api.ResourceDescriptorPropertyValue import ResourceDescriptorPropertyValue
         from netbluemind.resource.api.ResourceDescriptorPropertyValue import __ResourceDescriptorPropertyValueSerDer__
         propertiesValue = value['properties']
-        instance.properties = serder.ListSerDer(__ResourceDescriptorPropertyValueSerDer__()).parse(propertiesValue)
+        instance.properties = serder.ListSerDer(
+            __ResourceDescriptorPropertyValueSerDer__()).parse(propertiesValue)
         return instance
 
     def encode(self, value):
-        if(value == None):
+        if (value == None):
             return None
         instance = dict()
-        self.encodeInternal(value,instance)
+        self.encodeInternal(value, instance)
         return instance
 
     def encodeInternal(self, value, instance):
-        __DirBaseValueSerDer__().encodeInternal(value,instance)
+        __DirBaseValueSerDer__().encodeInternal(value, instance)
 
         labelValue = value.label
         instance["label"] = serder.STRING.encode(labelValue)
@@ -81,10 +85,11 @@ class __ResourceDescriptorSerDer__:
         from netbluemind.resource.api.ResourceReservationMode import ResourceReservationMode
         from netbluemind.resource.api.ResourceReservationMode import __ResourceReservationModeSerDer__
         reservationModeValue = value.reservationMode
-        instance["reservationMode"] = __ResourceReservationModeSerDer__().encode(reservationModeValue)
+        instance["reservationMode"] = __ResourceReservationModeSerDer__().encode(
+            reservationModeValue)
         from netbluemind.resource.api.ResourceDescriptorPropertyValue import ResourceDescriptorPropertyValue
         from netbluemind.resource.api.ResourceDescriptorPropertyValue import __ResourceDescriptorPropertyValueSerDer__
         propertiesValue = value.properties
-        instance["properties"] = serder.ListSerDer(__ResourceDescriptorPropertyValueSerDer__()).encode(propertiesValue)
+        instance["properties"] = serder.ListSerDer(
+            __ResourceDescriptorPropertyValueSerDer__()).encode(propertiesValue)
         return instance
-
