@@ -23,6 +23,7 @@ from netbluemind.python import serder
 
 class JobQuery:
     def __init__(self):
+        self.jobId = None
         self.statuses = None
         self.domain = None
         pass
@@ -41,6 +42,8 @@ class __JobQuerySerDer__:
         return instance
 
     def parseInternal(self, value, instance):
+        jobIdValue = value['jobId']
+        instance.jobId = serder.STRING.parse(jobIdValue)
         from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
         from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
         statusesValue = value['statuses']
@@ -59,6 +62,8 @@ class __JobQuerySerDer__:
 
     def encodeInternal(self, value, instance):
 
+        jobIdValue = value.jobId
+        instance["jobId"] = serder.STRING.encode(jobIdValue)
         from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
         from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
         statusesValue = value.statuses
